/* Generated file (by generator) */

/*
 * SPDX-FileCopyrightText: 2015 William Yu <williamyu@gnome.org>
 *
 * SPDX-License-Identifier: LGPL-2.1-only OR MPL-2.0
 */

#if !defined (__LIBICAL_GLIB_H_INSIDE__) && !defined (LIBICAL_GLIB_COMPILATION)
#error "Only <libical-glib/libical-glib.h> can be included directly."
#endif

#ifndef I_CAL_FORWARD_DECLARATIONS_H
#define I_CAL_FORWARD_DECLARATIONS_H

#include <glib-object.h>

G_BEGIN_DECLS

typedef struct _ICalArray ICalArray;
typedef struct _ICalAttach ICalAttach;
typedef struct _ICalCompIter ICalCompIter;
typedef struct _ICalComponent ICalComponent;
typedef struct _ICalDatetimeperiod ICalDatetimeperiod;
typedef struct _ICalDuration ICalDuration;
typedef struct _ICalEnumArray ICalEnumArray;
typedef struct _ICalGeo ICalGeo;
typedef struct _ICalParamIter ICalParamIter;
typedef struct _ICalParameter ICalParameter;
typedef struct _ICalParser ICalParser;
typedef struct _ICalPeriod ICalPeriod;
typedef struct _ICalPropIter ICalPropIter;
typedef struct _ICalProperty ICalProperty;
typedef struct _ICalRecurIterator ICalRecurIterator;
typedef struct _ICalRecurrence ICalRecurrence;
typedef struct _ICalReqstat ICalReqstat;
typedef struct _ICalStrArray ICalStrArray;
typedef struct _ICalTime ICalTime;
typedef struct _ICalTimeSpan ICalTimeSpan;
typedef struct _ICalTimezone ICalTimezone;
typedef struct _ICalTrigger ICalTrigger;
typedef struct _ICalValue ICalValue;
typedef struct _ICalVcardComponent ICalVcardComponent;
typedef struct _ICalVcardEnumArray ICalVcardEnumArray;
typedef struct _ICalVcardGeo ICalVcardGeo;
typedef struct _ICalVcardParameter ICalVcardParameter;
typedef struct _ICalVcardProperty ICalVcardProperty;
typedef struct _ICalVcardStrArray ICalVcardStrArray;
typedef struct _ICalVcardStructured ICalVcardStructured;
typedef struct _ICalVcardTime ICalVcardTime;
typedef struct _ICalVcardTz ICalVcardTz;
typedef struct _ICalVcardValue ICalVcardValue;

G_END_DECLS

#endif /* I_CAL_FORWARD_DECLARATIONS_H */
